@@ -23,7 +23,7 @@ class LivyJobSubmitter(AbstractJobSubmitter):
     # options is vendor specific arguments
     # args.conf is the spark job config
     # args is arguments need to pass to the main entry
-    def run(self, deployment_location, options={}, args={}, handlers=[]):
+    def run(self, deployment_location, options={}, args={}, handlers=[], on_job_submitted=None):
         bridge = self.config["bridge"]
         stage_dir = self.config['stage_dir']
         run_dir = self.config['run_dir']
@@ -57,12 +57,13 @@ class LivyJobSubmitter(AbstractJobSubmitter):
             'file': f'{deployment_location}/job_loader.py',
             'pyFiles': [f'{deployment_location}/app.zip'],
             'args': [
-                '--run-id', run_id, 
+                '--run-id', run_id,
                 '--run-dir', f"{run_dir}/{run_id}",
                 '--lib-url', f'{deployment_location}/lib.zip'
             ]
         }
         config.update(options)
+        config.pop("display_name", None)  # livy job submitter does not support display_name
 
         service_url = self.config['service_url']
         if service_url.endswith("/"):
@@ -88,13 +89,15 @@ class LivyJobSubmitter(AbstractJobSubmitter):
 
         print('job submitted')
         ret = json.loads(r.content.decode("utf8"))
+        if on_job_submitted is not None:
+            on_job_submitted(run_id, vendor_info=ret)
         job_id = ret['id']
         print('job id: {}'.format(job_id))
         print(ret)
         print('logs:')
         for log in ret.get('log', []):
             print(log)
-        
+            
         # pull the job status
         while True:
             r = requests.get(
